@@ -14,7 +14,7 @@
    +----------------------------------------------------------------------+
 */
 
-#define CONFIGURE_COMMAND " './configure'  'ax_cv_have_func_attribute_ifunc=no' '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--with-external-pcre' '--disable-intl' '--disable-posix' '--disable-opcache' '--disable-pdo' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=alpha--netbsd' '--host=alpha--netbsd' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=alpha--netbsd' 'host_alias=alpha--netbsd' 'PKG_CONFIG=/usr/pkg/bin/pkg-config' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/usr/pkg/lib/pkgconfig:/usr/pkg/share/pkgconfig:/usr/lib/pkgconfig:/usr/X11R7/lib/pkgconfig' 'LIBS='"
+#define CONFIGURE_COMMAND " './configure'  'ax_cv_have_func_attribute_ifunc=no' '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--with-external-pcre' '--disable-intl' '--disable-posix' '--disable-opcache' '--disable-pdo' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=aarch64--netbsd' '--host=aarch64--netbsd' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=aarch64--netbsd' 'host_alias=aarch64--netbsd' 'PKG_CONFIG=/usr/pkg/bin/pkg-config' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/usr/pkg/lib/pkgconfig:/usr/pkg/share/pkgconfig:/usr/lib/pkgconfig:/usr/X11R7/lib/pkgconfig' 'LIBS='"
 #define PHP_ODBC_CFLAGS	""
 #define PHP_ODBC_LFLAGS		""
 #define PHP_ODBC_LIBS		""
